@@ -22,6 +22,9 @@
 #include <log4cplus/internal/socket.h>
 #include <log4cplus/internal/internal.h>
 
+#if defined (LOG4CPLUS_WITH_UNIT_TESTS)
+#include <catch.hpp>
+#endif
 
 namespace log4cplus { namespace helpers {
 
@@ -263,4 +266,26 @@ openSocket(unsigned short port, bool udp, bool ipv6, SocketState& state)
 }
 
 
+#if defined (LOG4CPLUS_WITH_UNIT_TESTS)
+CATCH_TEST_CASE ("Socket", "[sockets]")
+{
+    CATCH_SECTION ("hostname resolution")
+    {
+        CATCH_SECTION ("FQDN")
+        {
+            auto result = getHostname(true);
+            CATCH_REQUIRE (result != LOG4CPLUS_C_STR_TO_TSTRING ("-"));
+
+        }
+
+        CATCH_SECTION ("non-FQDN")
+        {
+            auto result = getHostname(false);
+            CATCH_REQUIRE (result != LOG4CPLUS_C_STR_TO_TSTRING ("-"));
+        }
+    }
+}
+#endif // LOG4CPLUS_WITH_UNIT_TESTS
+
+
 } } // namespace log4cplus { namespace helpers {
